import logging
from os.path import expanduser

import typer

from alvin_cli import entity
from alvin_cli.config.loader import create_cfg_file
from alvin_cli.platforms import platform
from alvin_cli.utils import default_api
from alvin_cli.utils.helper_functions import console

app = typer.Typer()
app.add_typer(platform.app, name="platform")
app.add_typer(entity.app, name="entity")


def __setup_logging() -> None:
    logging.basicConfig(level=logging.INFO)


@app.command()
def setup() -> None:
    """Set up configuration file in root directory and input your alvin credentials"""
    directory = expanduser("~") + "/alvin"
    typer.secho(
        f"Created the cfg file in {directory}. Set up your credentials to start using other commands!",
        fg=typer.colors.BRIGHT_GREEN,
    )
    create_cfg_file(directory)


@app.command()
def current_user() -> None:
    """Get current authenticated user details"""
    user = default_api.get_user_info_api_v1_me_get()
    console.print(
        f'[bold yellow]User Email : {user["email"]}[/bold yellow], [bold cyan]User ID: {user["id"]}[/bold cyan], '
        f'[bold magenta]Org ID: {user["org_id"]}[/bold magenta], [bold green]Sha ID: {user["sha_id"]}[/bold green]'
    )


def run() -> None:
    app()


if __name__ == "__main__":
    run()  # pragma: no cover
